16.137. cdist-type__sensible_editor(7) — cdist 6.5.4 documentation

# 16.137. cdist-type__sensible_editor(7)

## 16.137.1. NAME

cdist-type__sensible_editor - Select the sensible-editor

## 16.137.2. DESCRIPTION

This cdist type allows you to select the sensible-editor for a given user.

## 16.137.3. REQUIRED PARAMETERS

editor

  Name or path of the editor to be selected. On systems other than Debian derivatives an absolute path is required.

  > It is permissible to omit this parameter if --state is absent.

## 16.137.4. OPTIONAL PARAMETERS

state

  'present', 'absent', or 'exists'. Defaults to 'present', where:

  present
    the sensible-editor is exactly what is specified in --editor.
  absent
    no sensible-editor configuration is present.
  exists
    the sensible-editor will be set to what is specified in --editor, unless there already is a configuration on the target system.

## 16.137.5. EXAMPLES

    __sensible_editor root --editor /bin/ed  # ed(1) is the standard
    __sensible_editor noob --editor nano

## 16.137.6. LIMITATIONS

This type depends upon the sensible-editor(1) script which is part of the sensible-utils package.

Therefore, the following operating systems are supported:
  - Debian 8 (jessie) or later
  - Devuan
  - Ubuntu 8.10 (intrepid) or later
  - RHEL/CentOS 7 or later (EPEL repo required)
  - Fedora 21 or later

Note: on old versions of Ubuntu the sensible-* utils are part of the debianutils package.

## 16.137.7. SEE ALSO

select-editor(1), sensible-editor(1).

## 16.137.8. AUTHOR

Dennis Camera <dennis.camera--@--ssrq-sds-fds.ch>

## 16.137.9. COPYING

Copyright (C) 2019 Dennis Camera. You can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.